SET client_encoding = 'UTF8';
SET standard_conforming_strings = off;
SET check_function_bodies = false;
SET client_min_messages = warning;
SET escape_string_warning = off;

SET search_path = setting, log, pg_catalog;

CREATE OR REPLACE FUNCTION add_cc_cfg_xcloud_platform( varchar, varchar, varchar ) RETURNS VOID AS
$$
BEGIN
	SET search_path = setting, log, pg_catalog;
	UPDATE cc_cfg_xcloud_platform SET cloud_platform_name=$2, description=$3 WHERE cloud_platform_id=$1;
	INSERT INTO cc_cfg_xcloud_platform (cloud_platform_id, cloud_platform_name, description)
		SELECT $1, $2, $3 WHERE NOT EXISTS (SELECT 1 FROM cc_cfg_xcloud_platform WHERE cloud_platform_id=$1);
END
$$ LANGUAGE plpgsql;

SELECT add_cc_cfg_xcloud_platform('AWS','Amazon Web Services','http://aws.amazon.com/jp/');

DROP FUNCTION add_cc_cfg_xcloud_platform( varchar, varchar, varchar );


CREATE OR REPLACE FUNCTION add_cc_collector_platform_mst( varchar, varchar, integer ) RETURNS VOID AS
$$
BEGIN
	SET search_path = setting, log, pg_catalog;
	UPDATE cc_collector_platform_mst SET platform_name=$2, order_no=$3 WHERE platform_id=$1;
	INSERT INTO cc_collector_platform_mst (platform_id, platform_name, order_no)
		SELECT $1, $2, $3 WHERE NOT EXISTS (SELECT 1 FROM cc_collector_platform_mst WHERE platform_id=$1);
END
$$ LANGUAGE plpgsql;

SELECT add_cc_collector_platform_mst('AWS','Amazon Web Services',110);
SELECT add_cc_collector_platform_mst('RDS','Amazon Relational Database Service',110);
SELECT add_cc_collector_platform_mst('ELB','Amazon Elastic Load Balancing',110);

DROP FUNCTION add_cc_collector_platform_mst( varchar, varchar, integer );


CREATE OR REPLACE FUNCTION add_cc_collector_sub_platform_mst( varchar, varchar, varchar, integer ) RETURNS VOID AS
$$
BEGIN
	SET search_path = setting, log, pg_catalog;
	UPDATE cc_collector_sub_platform_mst SET sub_platform_name=$2, type=$3, order_no=$4 WHERE sub_platform_id=$1;
	INSERT INTO cc_collector_sub_platform_mst (sub_platform_id, sub_platform_name, type, order_no)
		SELECT $1, $2, $3, $4 WHERE NOT EXISTS (SELECT 1 FROM cc_collector_sub_platform_mst WHERE sub_platform_id=$1);
END
$$ LANGUAGE plpgsql;

SELECT add_cc_collector_sub_platform_mst('AWS','Amazon Web Services','Cloud',110);

DROP FUNCTION add_cc_collector_sub_platform_mst( varchar, varchar, varchar, integer );


CREATE OR REPLACE FUNCTION add_cc_monitor_process_method_mst( varchar, varchar, varchar ) RETURNS VOID AS
$$
BEGIN
	SET search_path = setting, log, pg_catalog;
	UPDATE cc_monitor_process_method_mst SET collect_method=$3 WHERE platform_id=$1 AND sub_platform_id=$2;
	INSERT INTO cc_monitor_process_method_mst (platform_id, sub_platform_id, collect_method)
		SELECT $1, $2, $3 WHERE NOT EXISTS (SELECT 1 FROM cc_monitor_process_method_mst WHERE platform_id=$1 AND sub_platform_id=$2);
END
$$ LANGUAGE plpgsql;

SELECT add_cc_monitor_process_method_mst('LINUX','AWS','SNMP');
SELECT add_cc_monitor_process_method_mst('WINDOWS','AWS','SNMP');
SELECT add_cc_monitor_process_method_mst('NW_EQUIPMENT','AWS','SNMP');
SELECT add_cc_monitor_process_method_mst('OTHER','AWS','SNMP');

DROP FUNCTION add_cc_monitor_process_method_mst( varchar, varchar, varchar );


CREATE OR REPLACE FUNCTION add_cc_monitor_process_polling_mst( varchar, varchar, varchar, varchar, varchar, varchar ) RETURNS VOID AS
$$
BEGIN
	SET search_path = setting, log, pg_catalog;
	UPDATE cc_monitor_process_polling_mst SET entry_key=$5, polling_target=$6 WHERE collect_method = $1 AND platform_id=$2 AND sub_platform_id=$3 AND variable_id=$4;
	INSERT INTO cc_monitor_process_polling_mst (collect_method, platform_id, sub_platform_id, variable_id, entry_key, polling_target)
		SELECT $1, $2, $3, $4, $5, $6 WHERE NOT EXISTS (SELECT 1 FROM cc_monitor_process_polling_mst WHERE collect_method = $1 AND platform_id=$2 AND sub_platform_id=$3 AND variable_id=$4);
END
$$ LANGUAGE plpgsql;

SELECT add_cc_monitor_process_polling_mst('SNMP', 'LINUX','AWS','name', '.1.3.6.1.2.1.25.4.2.1.2.*', '.1.3.6.1.2.1.25.4.2.1.2');
SELECT add_cc_monitor_process_polling_mst('SNMP', 'LINUX','AWS','param', '.1.3.6.1.2.1.25.4.2.1.5.*', '.1.3.6.1.2.1.25.4.2.1.5');
SELECT add_cc_monitor_process_polling_mst('SNMP', 'LINUX','AWS','path', '.1.3.6.1.2.1.25.4.2.1.4.*', '.1.3.6.1.2.1.25.4.2.1.4');
SELECT add_cc_monitor_process_polling_mst('SNMP', 'WINDOWS','AWS','name', '.1.3.6.1.2.1.25.4.2.1.2.*', '.1.3.6.1.2.1.25.4.2.1.2');
SELECT add_cc_monitor_process_polling_mst('SNMP', 'WINDOWS','AWS','param', '.1.3.6.1.2.1.25.4.2.1.5.*', '.1.3.6.1.2.1.25.4.2.1.5');
SELECT add_cc_monitor_process_polling_mst('SNMP', 'WINDOWS','AWS','path', '.1.3.6.1.2.1.25.4.2.1.4.*', '.1.3.6.1.2.1.25.4.2.1.4');
SELECT add_cc_monitor_process_polling_mst('SNMP', 'NW_EQUIPMENT','AWS','name', '.1.3.6.1.2.1.25.4.2.1.2.*', '.1.3.6.1.2.1.25.4.2.1.2');
SELECT add_cc_monitor_process_polling_mst('SNMP', 'NW_EQUIPMENT','AWS','param', '.1.3.6.1.2.1.25.4.2.1.5.*', '.1.3.6.1.2.1.25.4.2.1.5');
SELECT add_cc_monitor_process_polling_mst('SNMP', 'NW_EQUIPMENT','AWS','path', '.1.3.6.1.2.1.25.4.2.1.4.*', '.1.3.6.1.2.1.25.4.2.1.4');
SELECT add_cc_monitor_process_polling_mst('SNMP', 'OTHER','AWS','name', '.1.3.6.1.2.1.25.4.2.1.2.*', '.1.3.6.1.2.1.25.4.2.1.2');
SELECT add_cc_monitor_process_polling_mst('SNMP', 'OTHER','AWS','param', '.1.3.6.1.2.1.25.4.2.1.5.*', '.1.3.6.1.2.1.25.4.2.1.5');
SELECT add_cc_monitor_process_polling_mst('SNMP', 'OTHER','AWS','path', '.1.3.6.1.2.1.25.4.2.1.4.*', '.1.3.6.1.2.1.25.4.2.1.4');

DROP FUNCTION add_cc_monitor_process_polling_mst( varchar, varchar, varchar, varchar, varchar, varchar );
